@@ -1,4 +1,6 @@
 MatchHierPageToEOLdata <- function(MyHiers, EOLdata){
+  if(any(MyHiers == "hierNA.xml"))
+  	MyHiers <- MyHiers[-which(MyHiers == "hierNA.xml")]
   matchedData <- matrix(nrow=length(MyHiers), ncol=3)
   #colnames(matchedData) <- c( "HierTaxon", "HierID", "eolID")
   matchedData[,2] <- as.character(sapply(MyHiers, GetHierID))
@@ -7,9 +9,9 @@ MatchHierPageToEOLdata <- function(MyHiers, EOLdata){
     matchedData[i,1] <- resOneFile[which(matchedData[i,2]==resOneFile[,6]), 1]
     matchedData[i,3] <- resOneFile[which(matchedData[i,2]==resOneFile[,6]), 4]
   }
-  matchedData <- data.frame(matchedData, stringsAsFactors=FALSE)
   matches <- match(matchedData[,3], EOLdata[,2])
   matchedData <- cbind(matchedData, EOLdata[matches, 3:dim(EOLdata)[2]])
   colnames(matchedData) <- c( "HierTaxon", "HierID", "eolID", colnames(EOLdata[3:dim(EOLdata)[2]]))
+  matchedData <- data.frame(matchedData, row.names=1, stringsAsFactors=FALSE)
   return(matchedData)
 }
